Enum sqlite_loadable::api::MprintfError
source · pub enum MprintfError {
Nul(NulError),
Oom,
}Expand description
Possible error cases when calling mprintf, aka the sqlite3_mprintf function.
pub enum MprintfError {
Nul(NulError),
Oom,
}Possible error cases when calling mprintf, aka the sqlite3_mprintf function.