Function sqlite_loadable::api::result_text
source · Expand description
Calls sqlite3_result_text
to represent that a function returns a string with the given value. Fails if
the string length is larger than i32 maximum value.
Calls sqlite3_result_text
to represent that a function returns a string with the given value. Fails if
the string length is larger than i32 maximum value.