Struct sqlite_loadable::errors::Error
source · pub struct Error(_);Expand description
Any error that occurs while creating or using a SQLite extension.
pub struct Error(_);Any error that occurs while creating or using a SQLite extension.