Struct sqlite_loadable::vtab_argparse::ColumnDeclaration
source · pub struct ColumnDeclaration {
pub name: String,
pub declared_type: Option<String>,
pub constraints: Option<String>,
}Expand description
A column declaration that defines a single column.
Example: "name text" would parse to a column with the name "name"
and declared type of "text".
Fields
name: StringName of declared column
declared_type: Option<String>constraints: Option<String>Implementations
sourceimpl ColumnDeclaration
impl ColumnDeclaration
sourcepub fn affinity(&self) -> ColumnAffinity
pub fn affinity(&self) -> ColumnAffinity
Determines the column declaration’s “affinity”, based on the parsed declared type. Uses the same rules as https://www.sqlite.org/datatype3.html#determination_of_column_affinity.
sourcepub fn vtab_declaration(&self) -> String
pub fn vtab_declaration(&self) -> String
Formats the column declaration into a way that a CREATE TABLE statement expects (“escaping” the column name).